summaryrefslogtreecommitdiffstats
path: root/kpackage/pkgOptions.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpackage/pkgOptions.h')
-rw-r--r--kpackage/pkgOptions.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/kpackage/pkgOptions.h b/kpackage/pkgOptions.h
index 1cf8d94..02a830f 100644
--- a/kpackage/pkgOptions.h
+++ b/kpackage/pkgOptions.h
@@ -32,7 +32,7 @@
#define PKGINSTALL_OPTIONS
#include "../config.h"
-// Qt headers
+// TQt headers
#include <tqframe.h>
#include <tqlayout.h>
#include <tqpushbutton.h>
@@ -52,8 +52,9 @@ class KPushButton;
class pkgOptions : public KDialog
{
Q_OBJECT
+ TQ_OBJECT
public:
- pkgOptions( pkgInterface *pki, TQWidget *parent=0, const TQString &caption=TQString::null);
+ pkgOptions( pkgInterface *pki, TQWidget *tqparent=0, const TQString &caption=TQString());
~pkgOptions();
bool setup(TQPtrList<packageInfo> *pl, const TQString &type);
@@ -103,8 +104,8 @@ signals:
void finished(int refresh);
protected:
- // The layout managers
- TQBoxLayout *layout, *hlayout, *vlayout;
+ // The tqlayout managers
+ TQBoxLayout *tqlayout, *htqlayout, *vtqlayout;
// Sub widgets
TQPushButton *installButton;
@@ -133,8 +134,9 @@ protected:
class pkgOptionsI: public pkgOptions
{
Q_OBJECT
+ TQ_OBJECT
public:
- pkgOptionsI(pkgInterface *pkg, TQWidget *parent = 0);
+ pkgOptionsI(pkgInterface *pkg, TQWidget *tqparent = 0);
TQString doPackages(int installFlags, TQPtrList<packageInfo> *p, bool &test);
};
@@ -143,8 +145,9 @@ public:
class pkgOptionsU: public pkgOptions
{
Q_OBJECT
+ TQ_OBJECT
public:
- pkgOptionsU(pkgInterface *pkg, TQWidget *parent = 0);
+ pkgOptionsU(pkgInterface *pkg, TQWidget *tqparent = 0);
TQString doPackages(int installFlags, TQPtrList<packageInfo> *p, bool &test);
};